<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="sq">
<context>
    <name>NetFileChooseEdit</name>
    <message>
        <source>All files (*)</source>
        <translation>Krejt kartelat (*)</translation>
    </message>
</context>
<context>
    <name>NetPasswordEdit</name>
    <message>
        <source>Required</source>
        <translation>E domosdoshme</translation>
    </message>
</context>
<context>
    <name>PageAirplane</name>
    <message>
        <source>Airplane mode</source>
        <translation>Mënyra aeroplan</translation>
    </message>
    <message>
        <source>Stop wireless communication</source>
        <translation>Ndal lidhje pa fill</translation>
    </message>
    <message>
        <source>Enabling the airplane mode turns off wireless network, personal hotspot and Bluetooth</source>
        <translation>Aktivizimi i mënyrës aeroplan çaktivizon rrjetin pa fill, hotspot-in personal dhe Bluetooth-in</translation>
    </message>
</context>
<context>
    <name>PageAppProxy</name>
    <message>
        <source>Application Proxy</source>
        <translation>Ndërmjetës Aplikacioni</translation>
    </message>
    <message>
        <source>Set up proxy servers</source>
        <translation>Ujdisni shërbyes ndërmjetës</translation>
    </message>
    <message>
        <source>Proxy Type</source>
        <translation>Lloj Ndërmjetësi</translation>
    </message>
    <message>
        <source>http</source>
        <translation>http</translation>
    </message>
    <message>
        <source>socks4</source>
        <translation>socks4</translation>
    </message>
    <message>
        <source>socks5</source>
        <translation>socks5</translation>
    </message>
    <message>
        <source>IP Address</source>
        <translation>Adresë IP</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>E domosdoshme</translation>
    </message>
    <message>
        <source>Invalid IP address</source>
        <translation>Adresë IP e pavlefshme</translation>
    </message>
    <message>
        <source>Port</source>
        <translation>Portë</translation>
    </message>
    <message>
        <source>Invalid port</source>
        <translation>Portë e pavlefshme</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Emër përdoruesi</translation>
    </message>
    <message>
        <source>Optional</source>
        <translation>Opsionale</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Fjalëkalim</translation>
    </message>
    <message>
        <source>Check &quot;Use a proxy&quot; in application context menu in Launcher after configured</source>
        <translation>Pas formësimit, i vini shenjë “Përdor ndërmjetës” te menuja e kontekstit të aplikacionit te Nisësi</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Anuloje</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Ruaje</translation>
    </message>
</context>
<context>
    <name>PageDSL</name>
    <message>
        <source>DSL</source>
        <translation>DSL</translation>
    </message>
    <message>
        <source>Set up a dial-up network connection</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Disconnect</source>
        <translation>Shkëpute</translation>
    </message>
    <message>
        <source>Connect</source>
        <translation>Lidhu</translation>
    </message>
    <message>
        <source>Add PPPoE connection</source>
        <translation>Shtoni lidhje PPPoE</translation>
    </message>
</context>
<context>
    <name>PageDSLSettings</name>
    <message>
        <source> Network Properties</source>
        <translation>Veti Rrjeti</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Fshije</translation>
    </message>
    <message>
        <source>Are you sure you want to delete this configuration?</source>
        <translation>Jeni i sigurt se doni të fshihet ky formësim?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Anuloje</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Ruaje</translation>
    </message>
</context>
<context>
    <name>PageDetails</name>
    <message>
        <source>Network Details</source>
        <translation>Hollësi Rrjeti</translation>
    </message>
    <message>
        <source>View all network configurations</source>
        <translation>Shihni krejt formësimet e rrjetit</translation>
    </message>
    <message>
        <source>Details has been copied</source>
        <translation>Hollësitë u kopjuan</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Kopjoje</translation>
    </message>
    <message>
        <source>Select All</source>
        <translation>Përzgjidhi Krejt</translation>
    </message>
    <message>
        <source>Network Detection</source>
        <translation>Pikasje Rrjeti</translation>
    </message>
</context>
<context>
    <name>PageHotspot</name>
    <message>
        <source>WPA/WPA2 Personal</source>
        <translation>WPA/WPA2 Personal</translation>
    </message>
    <message>
        <source>WPA3 Personal</source>
        <translation>WPA3 Personal</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Asnjë</translation>
    </message>
    <message>
        <source>2.4 GHz</source>
        <translation>2.4 GHz</translation>
    </message>
    <message>
        <source>5 GHz</source>
        <translation>5 GHz</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>Auto</translation>
    </message>
    <message>
        <source>Not Bind</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Personal Hotspot</source>
        <translation>Hotspot Personal</translation>
    </message>
    <message>
        <source>Share the network</source>
        <translation>Ndajeni rrjetin me të tjerë</translation>
    </message>
    <message>
        <source>My Hotspot</source>
        <translation>Hotspot-i Im</translation>
    </message>
    <message>
        <source>Edit My Hotspot</source>
        <translation>Përpunoni Hotspot-in Tuaj</translation>
    </message>
    <message>
        <source>Name (SSID)</source>
        <translation>Emër (SSID)</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>E domosdoshme</translation>
    </message>
    <message>
        <source>Security</source>
        <translation>Siguri</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Fjalëkalim</translation>
    </message>
    <message>
        <source>Band</source>
        <translation>Bandë</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Anuloje</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Ruaje</translation>
    </message>
    <message>
        <source>Shared Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Hotspot Sharing Device</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>If you want to use the personal hotspot, disable Airplane Mode first and then enable the wireless network adapter.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>If you want to use the personal hotspot, disable &lt;a style=&apos;text-decoration: none;&apos; href=&apos;network/airplaneMode&apos;&gt;Airplane Mode&lt;/a&gt; first and then enable the wireless network adapter.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PageSettings</name>
    <message>
        <source> Network Properties</source>
        <translation>Veti Rrjeti</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Fshije</translation>
    </message>
    <message>
        <source>Are you sure you want to delete this configuration?</source>
        <translation>Jeni i sigurt se doni të fshihet ky formësim?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Anuloje</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Ruaje</translation>
    </message>
</context>
<context>
    <name>PageSystemProxy</name>
    <message>
        <source>System Proxy</source>
        <translation>Ndërmjetës Sistemi</translation>
    </message>
    <message>
        <source>Set up proxy servers</source>
        <translation>Ujdisni shërbyes ndërmjetës</translation>
    </message>
    <message>
        <source>Proxy Type</source>
        <translation>Lloj Ndërmjetësi</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>Auto</translation>
    </message>
    <message>
        <source>Manual</source>
        <translation>Dorazi</translation>
    </message>
    <message>
        <source>Configuration URL</source>
        <translation>URL Formësimi</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>E domosdoshme</translation>
    </message>
    <message>
        <source>HTTP Proxy</source>
        <translation>Ndërmjetës HTTP</translation>
    </message>
    <message>
        <source>HTTPS Proxy</source>
        <translation>Ndërmjetës HTTPS</translation>
    </message>
    <message>
        <source>FTP Proxy</source>
        <translation>Ndërmjetës FTP</translation>
    </message>
    <message>
        <source>SOCKS Proxy</source>
        <translation>Ndërmjetës SOCKS</translation>
    </message>
    <message>
        <source>Ignore the proxy configurations for the above hosts and domains</source>
        <translation>Shpërfilli formësimet e ndërmjetësve për strehët dhe përkatësitë më sipër</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Anuloje</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Ruaje</translation>
    </message>
</context>
<context>
    <name>PageVPN</name>
    <message>
        <source>VPN</source>
        <translation>VPN</translation>
    </message>
    <message>
        <source>Connect, add, import</source>
        <translation>Lidhuni, shtoni, importoni</translation>
    </message>
    <message>
        <source>Disconnect</source>
        <translation>Shkëputu</translation>
    </message>
    <message>
        <source>Connect</source>
        <translation>Lidhu</translation>
    </message>
    <message>
        <source>Add VPN</source>
        <translation>Shtoni VPN</translation>
    </message>
    <message>
        <source>Import VPN</source>
        <translation>Importoni VPN</translation>
    </message>
    <message>
        <source>*.conf</source>
        <translation>*.conf</translation>
    </message>
    <message>
        <source>Import Error</source>
        <translation>Gabim Importimi</translation>
    </message>
    <message>
        <source>File error</source>
        <translation>Gabim kartele</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
</context>
<context>
    <name>PageVPNSettings</name>
    <message>
        <source> Network Properties</source>
        <translation>Veti Rrjeti</translation>
    </message>
    <message>
        <source>VPN Type</source>
        <translation>Lloj VPN-je</translation>
    </message>
    <message>
        <source>L2TP</source>
        <translation>L2TP</translation>
    </message>
    <message>
        <source>PPTP</source>
        <translation>PPTP</translation>
    </message>
    <message>
        <source>OpenVPN</source>
        <translation>OpenVPN</translation>
    </message>
    <message>
        <source>OpenConnect</source>
        <translation>OpenConnect</translation>
    </message>
    <message>
        <source>StrongSwan</source>
        <translation>StrongSwan</translation>
    </message>
    <message>
        <source>VPNC</source>
        <translation>VPNC</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Fshije</translation>
    </message>
    <message>
        <source>Are you sure you want to delete this configuration?</source>
        <translation>Jeni i sigurt se doni të fshihet ky formësim?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Anuloje</translation>
    </message>
    <message>
        <source>Export</source>
        <translation>Eksportoje</translation>
    </message>
    <message>
        <source>*.conf</source>
        <translation>*.conf</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Ruaje</translation>
    </message>
</context>
<context>
    <name>PageWiredDevice</name>
    <message>
        <source>Connect, edit network settings</source>
        <translation>Lidhuni, përpunoni rregullime rrjeti</translation>
    </message>
    <message>
        <source>Plug in the network cable first</source>
        <translation>Së pari, vendosni kabllon e rrjetit</translation>
    </message>
    <message>
        <source>Disconnect</source>
        <translation>Shkëputu</translation>
    </message>
    <message>
        <source>Connect</source>
        <translation>Lidhu</translation>
    </message>
    <message>
        <source>Add Network Connection</source>
        <translation>Shtoni Lidhje Rrjeti</translation>
    </message>
</context>
<context>
    <name>PageWirelessDevice</name>
    <message>
        <source>Connect, edit network settings</source>
        <translation>Lidhuni, përpunoni rregullime rrjeti</translation>
    </message>
    <message>
        <source>Disconnect</source>
        <translation>Shkëputu</translation>
    </message>
    <message>
        <source>Connect</source>
        <translation>Lidhu</translation>
    </message>
    <message>
        <source>My&#xa0;Networks</source>
        <translation>Rrjetet&#xa0;e Mi</translation>
    </message>
    <message>
        <source>Other Networks</source>
        <translation>Rrjete të Tjerë</translation>
    </message>
    <message>
        <source>Disable Airplane Mode first if you want to connect to a wireless network</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Disable &lt;a style=&apos;text-decoration: none;&apos; href=&apos;network/airplaneMode&apos;&gt;Airplane Mode&lt;/a&gt; first if you want to connect to a wireless network</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Disable hotspot first if you want to connect to a wireless network</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&lt;a style=&apos;text-decoration: none;&apos; href=&apos;NetHotspotControlItem&apos;&gt;Disable hotspot&lt;/a&gt; first if you want to connect to a wireless network</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SectionDNS</name>
    <message>
        <source>DNS</source>
        <translation>DNS</translation>
    </message>
    <message>
        <source>Done</source>
        <translation>U bë</translation>
    </message>
    <message>
        <source>Edit</source>
        <translation>Përpunojeni</translation>
    </message>
    <message>
        <source>Invalid IP address</source>
        <translation>Adresë IP e pavlefshme</translation>
    </message>
</context>
<context>
    <name>SectionDevice</name>
    <message>
        <source>Not Bind</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>WLAN</source>
        <translation>WLAN</translation>
    </message>
    <message>
        <source>Ethernet</source>
        <translation>Ethernet</translation>
    </message>
    <message>
        <source>Device MAC Addr</source>
        <translation>Adresë MAC e pajisjes</translation>
    </message>
    <message>
        <source>Cloned MAC Addr</source>
        <translation>Adresë MAC e klonuar</translation>
    </message>
    <message>
        <source>Customize MTU</source>
        <translation>Përshtatni MTU</translation>
    </message>
    <message>
        <source>MTU</source>
        <translation>MTU</translation>
    </message>
    <message>
        <source>Band</source>
        <translation>Bandë</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>Auto</translation>
    </message>
    <message>
        <source>2.4 GHz</source>
        <translation>2.4 GHz</translation>
    </message>
    <message>
        <source>5 GHz</source>
        <translation>5 GHz</translation>
    </message>
</context>
<context>
    <name>SectionGeneric</name>
    <message>
        <source>General</source>
        <translation>Të përgjithshme</translation>
    </message>
    <message>
        <source>Name (SSID)</source>
        <translation>Emër (SSID)</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>Emër</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>E domosdoshme</translation>
    </message>
    <message>
        <source>Auto Connect</source>
        <translation>Vetëlidhu</translation>
    </message>
</context>
<context>
    <name>SectionIPv4</name>
    <message>
        <source>IPv4</source>
        <translation>IPv4</translation>
    </message>
    <message>
        <source>Done</source>
        <translation>U bë</translation>
    </message>
    <message>
        <source>Edit</source>
        <translation>Përpunojeni</translation>
    </message>
    <message>
        <source>Disabled</source>
        <translation>E çaktivizuar</translation>
    </message>
    <message>
        <source>Manual</source>
        <translation>Dorazi</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>Auto</translation>
    </message>
    <message>
        <source>Method</source>
        <translation>Metodë</translation>
    </message>
    <message>
        <source>Only applied in corresponding resources</source>
        <translation>Aplikuar vetëm mbi burimet përkatëse</translation>
    </message>
    <message>
        <source>IP Address</source>
        <translation>Adresë IP</translation>
    </message>
    <message>
        <source>Invalid IP address</source>
        <translation>Adresë IP e pavlefshme</translation>
    </message>
    <message>
        <source>Netmask</source>
        <translation>Netmask-ë</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Kanal</translation>
    </message>
    <message>
        <source>Invalid netmask</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation type="unfinished">Kanal i pavlefshëm</translation>
    </message>
    <message>
        <source>Duplicate IP address</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SectionIPv6</name>
    <message>
        <source>Disabled</source>
        <translation>E çaktivizuar</translation>
    </message>
    <message>
        <source>Manual</source>
        <translation>Dorazi</translation>
    </message>
    <message>
        <source>Ignore</source>
        <translation>Shpërfille</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>Auto</translation>
    </message>
    <message>
        <source>IPv6</source>
        <translation>IPv6</translation>
    </message>
    <message>
        <source>Done</source>
        <translation>U bë</translation>
    </message>
    <message>
        <source>Edit</source>
        <translation>Përpunoni</translation>
    </message>
    <message>
        <source>Method</source>
        <translation>Metodë</translation>
    </message>
    <message>
        <source>Only applied in corresponding resources</source>
        <translation>Aplikuar vetëm mbi burimet përkatëse</translation>
    </message>
    <message>
        <source>IP Address</source>
        <translation>Adresë IP</translation>
    </message>
    <message>
        <source>Invalid IP address</source>
        <translation>Adresë IP e pavlefshme</translation>
    </message>
    <message>
        <source>Prefix</source>
        <translation>Parashtesë</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Kanal</translation>
    </message>
    <message>
        <source>Invalid netmask</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Duplicate IP address</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation type="unfinished">Kanal i pavlefshëm</translation>
    </message>
</context>
<context>
    <name>SectionPPP</name>
    <message>
        <source>PPP</source>
        <translation>PPP</translation>
    </message>
    <message>
        <source>Use MPPE</source>
        <translation>Përdor MPPE</translation>
    </message>
    <message>
        <source>128-bit MPPE</source>
        <translation>MPPE 128-bit</translation>
    </message>
    <message>
        <source>Stateful MPPE</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Refuse EAP Authentication</source>
        <translation>Mos prano Mirëfilltësim EAP</translation>
    </message>
    <message>
        <source>Refuse PAP Authentication</source>
        <translation>Mos prano Mirëfilltësim PAP</translation>
    </message>
    <message>
        <source>Refuse CHAP Authentication</source>
        <translation>Mos prano Mirëfilltësim CHAP</translation>
    </message>
    <message>
        <source>Refuse MSCHAP Authentication</source>
        <translation>Mos prano Mirëfilltësim MSCHAP</translation>
    </message>
    <message>
        <source>Refuse MSCHAPv2 Authentication</source>
        <translation>Mos prano Mirëfilltësim MSCHAPv2</translation>
    </message>
    <message>
        <source>No BSD Data Compression</source>
        <translation>Pa Ngjeshje BSD të Dhënash</translation>
    </message>
    <message>
        <source>No Deflate Data Compression</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>No TCP Header Compression</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Send PPP Echo Packets</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SectionPPPOE</name>
    <message>
        <source>PPPoE</source>
        <translation>PPPoE</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Emër përdoruesi</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>E domosdoshme</translation>
    </message>
    <message>
        <source>Service</source>
        <translation>Shërbim</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Fjalëkalim</translation>
    </message>
</context>
<context>
    <name>SectionSecret</name>
    <message>
        <source>Security</source>
        <translation>Siguri</translation>
    </message>
    <message>
        <source>TLS</source>
        <translation>TLS</translation>
    </message>
    <message>
        <source>MD5</source>
        <translation>MD5</translation>
    </message>
    <message>
        <source>FAST</source>
        <translation>FAST</translation>
    </message>
    <message>
        <source>Tunneled TLS</source>
        <translation>TLS përmes tuneli</translation>
    </message>
    <message>
        <source>Protected EAP</source>
        <translation>EAP i mbrojtur</translation>
    </message>
    <message>
        <source>LEAP</source>
        <translation>LEAP</translation>
    </message>
    <message>
        <source>GTC</source>
        <translation>GTC</translation>
    </message>
    <message>
        <source>MSCHAPV2</source>
        <translation>MSCHAPV2</translation>
    </message>
    <message>
        <source>PAP</source>
        <translation>PAP</translation>
    </message>
    <message>
        <source>MSCHAP</source>
        <translation>MSCHAP</translation>
    </message>
    <message>
        <source>CHAP</source>
        <translation>CHAP</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Asnjë</translation>
    </message>
    <message>
        <source>WEP</source>
        <translation>WEP</translation>
    </message>
    <message>
        <source>WPA/WPA2 Personal</source>
        <translation>WPA/WPA2 Personal</translation>
    </message>
    <message>
        <source>WPA/WPA2 Enterprise</source>
        <translation>WPA/WPA2 Enterprise</translation>
    </message>
    <message>
        <source>WPA3 Personal</source>
        <translation>WPA3 Personal</translation>
    </message>
    <message>
        <source>EAP Auth</source>
        <translation>Mirëfilltësim EAP</translation>
    </message>
    <message>
        <source>Identity</source>
        <translation>Identitet</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>E domosdoshme</translation>
    </message>
    <message>
        <source>Pwd Options</source>
        <translation>Mundësi Fjalëkalimi</translation>
    </message>
    <message>
        <source>Save password for this user</source>
        <translation>Ruaje fjalëkalimin për këtë përdorues</translation>
    </message>
    <message>
        <source>Save password for all users</source>
        <translation>Ruaj fjalëkalim për krejt përdoruesit</translation>
    </message>
    <message>
        <source>Ask me always</source>
        <translation>Pyetmë përherë</translation>
    </message>
    <message>
        <source>Key</source>
        <translation>Kyç</translation>
    </message>
    <message>
        <source>Private Pwd</source>
        <translation>Fjalëkalim Privat</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Fjalëkalim</translation>
    </message>
    <message>
        <source>Authentication</source>
        <translation>Mirëfilltësim</translation>
    </message>
    <message>
        <source>Shared key</source>
        <translation>Kyç i përbashkët</translation>
    </message>
    <message>
        <source>Open system</source>
        <translation>Sistem i hapur</translation>
    </message>
    <message>
        <source>Private Key</source>
        <translation>Kyç Privat</translation>
    </message>
    <message>
        <source>Anonymous ID</source>
        <translation>ID anonime</translation>
    </message>
    <message>
        <source>Provisioning</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Disabled</source>
        <translation>E çaktivizuar</translation>
    </message>
    <message>
        <source>Anonymous</source>
        <translation>I paemër</translation>
    </message>
    <message>
        <source>Authenticated</source>
        <translation>I mirëfilltësuar</translation>
    </message>
    <message>
        <source>Both</source>
        <translation>Të dyja</translation>
    </message>
    <message>
        <source>PAC file</source>
        <translation>Kartelë Pac</translation>
    </message>
    <message>
        <source>CA Cert</source>
        <translation>Dëshmi AD-je</translation>
    </message>
    <message>
        <source>User Cert</source>
        <translation>Dëshmi Përdoruesi</translation>
    </message>
    <message>
        <source>PEAP Version</source>
        <translation>Version PEAP</translation>
    </message>
    <message>
        <source>Automatic</source>
        <translation>Automatik</translation>
    </message>
    <message>
        <source>Version 0</source>
        <translation>Version 0</translation>
    </message>
    <message>
        <source>Version 1</source>
        <translation>Version 1</translation>
    </message>
    <message>
        <source>Inner Auth</source>
        <translation>Mirëfilltësim i Brendshëm</translation>
    </message>
</context>
<context>
    <name>SectionVPN</name>
    <message>
        <source>VPN</source>
        <translation>VPN</translation>
    </message>
    <message>
        <source>All files (*)</source>
        <translation>Krejt kartelat (*)</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>E domosdoshme</translation>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation>Kanal i pavlefshëm</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Kanal</translation>
    </message>
    <message>
        <source>CA Cert</source>
        <translation>Dëshmi AD-je</translation>
    </message>
    <message>
        <source>Proxy</source>
        <translation>Ndërmjetës</translation>
    </message>
    <message>
        <source>Allow Cisco Secure Desktop Trojan</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>CSD Script</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Auth Type</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Private Key</source>
        <translation type="unfinished">Kyç Privat</translation>
    </message>
    <message>
        <source>SSH Agent</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Smart Card</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>EAP</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Pre-Shared Key</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>User Cert</source>
        <translation type="unfinished">Dëshmi Përdoruesi</translation>
    </message>
    <message>
        <source>Username</source>
        <translation type="unfinished">Emër përdoruesi</translation>
    </message>
    <message>
        <source>Use FSID for Key Passphrase</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Certificates (TLS)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Password</source>
        <translation type="unfinished">Fjalëkalim</translation>
    </message>
    <message>
        <source>Certificates with Password (TLS)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Static Key</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Pwd Options</source>
        <translation type="unfinished">Mundësi Fjalëkalimi</translation>
    </message>
    <message>
        <source>Saved</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ask</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Not Required</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Private Pwd</source>
        <translation type="unfinished">Fjalëkalim Privat</translation>
    </message>
    <message>
        <source>Customize Key Direction</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Key Direction</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>0</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Remote IP</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Local IP</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>NT Domain</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Request an Inner IP Address</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Enforce UDP Encapsulation</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Use IP Compression</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Enable Custom Cipher Proposals</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>IKE</source>
        <translation>`IKE</translation>
    </message>
    <message>
        <source>ESP</source>
        <translation>ESP</translation>
    </message>
    <message>
        <source>Group Name</source>
        <translation>Emër Grupi</translation>
    </message>
    <message>
        <source>Group Pwd</source>
        <translation>Fjalëkalim Grupi</translation>
    </message>
    <message>
        <source>Use Hybrid Authentication</source>
        <translation>Përdor Mirëfilltësim Hibrid</translation>
    </message>
    <message>
        <source>CA File</source>
        <translation>Kartelë AD</translation>
    </message>
    <message>
        <source>VPN PPP</source>
        <translation>VPN PPP</translation>
    </message>
    <message>
        <source>Use MPPE</source>
        <translation>Përdor MPPE</translation>
    </message>
    <message>
        <source>Security</source>
        <translation>Siguri</translation>
    </message>
    <message>
        <source>All Available (default)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>40-bit (less secure)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>128-bit (most secure)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Stateful MPPE</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Refuse EAP Authentication</source>
        <translation type="unfinished">Mos prano Mirëfilltësim EAP</translation>
    </message>
    <message>
        <source>Refuse PAP Authentication</source>
        <translation type="unfinished">Mos prano Mirëfilltësim PAP</translation>
    </message>
    <message>
        <source>Refuse CHAP Authentication</source>
        <translation type="unfinished">Mos prano Mirëfilltësim CHAP</translation>
    </message>
    <message>
        <source>Refuse MSCHAP Authentication</source>
        <translation type="unfinished">Mos prano Mirëfilltësim MSCHAP</translation>
    </message>
    <message>
        <source>Refuse MSCHAPv2 Authentication</source>
        <translation type="unfinished">Mos prano Mirëfilltësim MSCHAPv2</translation>
    </message>
    <message>
        <source>No BSD Data Compression</source>
        <translation type="unfinished">Pa Ngjeshje BSD të Dhënash</translation>
    </message>
    <message>
        <source>No Deflate Data Compression</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>No TCP Header Compression</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>No Protocol Field Compression</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>No Address/Control Compression</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Send PPP Echo Packets</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>VPN IPsec</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Enable IPsec</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Group ID</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Phase1 Algorithms</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Phase2 Algorithms</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>VPN Advanced</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Customize Gateway Port</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Gateway Port</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Customize Renegotiation Interval</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Renegotiation Interval</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Use LZO Data Compression</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Use TCP Connection</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Use TAP Device</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Customize Tunnel MTU</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>MTU</source>
        <translation type="unfinished">MTU</translation>
    </message>
    <message>
        <source>Customize UDP Fragment Size</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>UDP Fragment Size</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Restrict Tunnel TCP MSS</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Randomize Remote Hosts</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Domain</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Vendor</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cisco (default)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Netscreen</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Version</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Encryption</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Secure (default)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Weak</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>None</source>
        <translation type="unfinished">Asnjë</translation>
    </message>
    <message>
        <source>NAT Traversal Mode</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>NAT-T When Available (default)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>NAT-T Always</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cisco UDP</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Disabled</source>
        <translation type="unfinished">E çaktivizuar</translation>
    </message>
    <message>
        <source>IKE DH Group</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>DH Group 1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>DH Group 2 (default)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>DH Group 5</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Forward Secrecy</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Server (default)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>DH Group 2</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Local Port</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Disable Dead Peer Detection</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>VPN Security</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cipher</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Default</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>DES-CBC</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>RC2-CBC</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>DES-EDE-CBC</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>DES-EDE3-CBC</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>DESX-CBC</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>BF-CBC</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>RC2-40-CBC</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>CAST5-CBC</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>RC2-64-CBC</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>AES-128-CBC</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>AES-192-CBC</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>AES-256-CBC</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>CAMELLIA-128-CBC</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>CAMELLIA-192-CBC</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>CAMELLIA-256-CBC</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>SEED-CBC</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>HMAC Auth</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>RSA MD-4</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>MD-5</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>SHA-1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>SHA-224</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>SHA-256</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>SHA-384</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>SHA-512</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>RIPEMD-160</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>VPN Proxy</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Proxy Type</source>
        <translation type="unfinished">Lloj Ndërmjetësi</translation>
    </message>
    <message>
        <source>HTTP</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>SOCKS</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Server IP</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Port</source>
        <translation type="unfinished">Portë</translation>
    </message>
    <message>
        <source>Retry Indefinitely When Failed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>VPN TLS Authentication</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Subject Match</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Remote Cert Type</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Client</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Server</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Key File</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SystemProxyConfigItem</name>
    <message>
        <source>Optional</source>
        <translation type="unfinished">Opsionale</translation>
    </message>
    <message>
        <source>Port</source>
        <translation type="unfinished">Portë</translation>
    </message>
    <message>
        <source>Authentication is required</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Username</source>
        <translation type="unfinished">Emër përdoruesi</translation>
    </message>
    <message>
        <source>Required</source>
        <translation type="unfinished">E domosdoshme</translation>
    </message>
    <message>
        <source>Password</source>
        <translation type="unfinished">Fjalëkalim</translation>
    </message>
</context>
<context>
    <name>dde::network::NetAirplaneModeTipsItem</name>
    <message>
        <source>Disable &lt;a style=&quot;text-decoration: none;&quot; href=&quot;Airplane Mode&quot;&gt;Airplane Mode&lt;/a&gt; first if you want to connect to a wireless network</source>
        <translation>Nëse doni të lidheni me një rrjet pa fill, së pari çaktivizoni &lt;a href=&quot;Airplane Mode&quot;&gt;Mënyrën Aeroplan&lt;/a&gt;</translation>
    </message>
</context>
<context>
    <name>dde::network::NetManagerPrivate</name>
    <message>
        <source>IP conflict</source>
        <translation>Përplasje IP-sh</translation>
    </message>
    <message>
        <source>Network</source>
        <translation>Rrjet</translation>
    </message>
</context>
<context>
    <name>dde::network::NetManagerThreadPrivate</name>
    <message>
        <source>Wired Connection %1</source>
        <translation>Lidhje Me Fill %1</translation>
    </message>
    <message>
        <source>VPN L2TP %1</source>
        <translation>VPN L2TP %1</translation>
    </message>
    <message>
        <source>VPN PPTP %1</source>
        <translation>VPN PPTP %1</translation>
    </message>
    <message>
        <source>VPN VPNC %1</source>
        <translation>VPN VPNC %1</translation>
    </message>
    <message>
        <source>VPN OpenVPN %1</source>
        <translation>VPN OpenVPN %1</translation>
    </message>
    <message>
        <source>VPN StrongSwan %1</source>
        <translation>VPN StrongSwan %1</translation>
    </message>
    <message>
        <source>VPN OpenConnect %1</source>
        <translation>VPN OpenConnect %1</translation>
    </message>
    <message>
        <source>PPPoE Connection %1</source>
        <translation>Lidhje PPPoE %1</translation>
    </message>
    <message>
        <source>Connecting &quot;%1&quot;</source>
        <translation>Po lidhet me “%1”</translation>
    </message>
    <message>
        <source>&quot;%1&quot; connected</source>
        <translation>“%1” u lidh</translation>
    </message>
    <message>
        <source>&quot;%1&quot; disconnected</source>
        <translation>“%1” u shkëput</translation>
    </message>
    <message>
        <source>Unable to connect &quot;%1&quot;, please check your router or net cable.</source>
        <translation>S’arrihet të lidhet me “%1”, ju lutemi, kontrolloni rrugëzuesin tuaj ose kabllon e rrjetit.</translation>
    </message>
    <message>
        <source>Unable to connect &quot;%1&quot;, please keep closer to the wireless router</source>
        <translation>S’arrihet të lidhet me “%1”, ju lutemi, rrini më afër rrugëzuesit pa fill</translation>
    </message>
    <message>
        <source>Connection failed, unable to connect &quot;%1&quot;, wrong password</source>
        <translation>Lidhja dështoi, s’arrihet të lidhet me “%1”, fjalëkalim i gabuar</translation>
    </message>
    <message>
        <source>Password is required to connect &quot;%1&quot;</source>
        <translation>Për t’u lidhur me “%1”, lypset fjalëkalim</translation>
    </message>
    <message>
        <source>The &quot;%1&quot; 802.11 WLAN network could not be found</source>
        <translation>Rrjeti 802.11 WLAN “%1” s’u gjet dot</translation>
    </message>
    <message>
        <source>To connect &quot;%1&quot;, please set up your authentication info after logging in</source>
        <translation>Që të bëhet lidhja me “%1”, ju lutemi, ujdisni hollësitë tuaja për mirëfilltësimin, pasi të bëni hyrjen</translation>
    </message>
</context>
<context>
    <name>dde::network::NetSystemProxyControlItem</name>
    <message>
        <source>System Proxy</source>
        <translation>Ndërmjetës Sistemi</translation>
    </message>
</context>
<context>
    <name>dde::network::NetVPNTipsItem</name>
    <message>
        <source>VPN configuration is not connected or failed to connect. Please &lt;a style=&quot;text-decoration: none;&quot; href=&quot;go to the control center&quot;&gt;go to the control center&lt;/a&gt; for inspection.</source>
        <translation>Formësimi i VPN-së s’u përdor, ose s’u arrit të bëhet lidhje. Ju lutemi, për të parë se si është puna, &lt;a style=&quot;text-decoration: none;&quot; href=&quot;go to the control center&quot;&gt;kaloni te qendër kontrolli&lt;/a&gt;.</translation>
    </message>
</context>
<context>
    <name>dde::network::NetWiredControlItem</name>
    <message>
        <source>Wired Network</source>
        <translation>Rrjet Me Fill</translation>
    </message>
</context>
<context>
    <name>dde::network::NetWirelessControlItem</name>
    <message>
        <source>Wireless Network</source>
        <translation>Rrjet Pa Fill</translation>
    </message>
</context>
<context>
    <name>dde::network::NetWirelessHiddenItem</name>
    <message>
        <source>Connect to hidden network</source>
        <translation>Lidhu në rrjet të fshehur</translation>
    </message>
</context>
<context>
    <name>dde::network::NetWirelessMineItem</name>
    <message>
        <source>My Networks</source>
        <translation>Rrjetet e Mi</translation>
    </message>
</context>
<context>
    <name>dde::network::NetWirelessOtherItem</name>
    <message>
        <source>Other Networks</source>
        <translation>Rrjete të Tjerë</translation>
    </message>
</context>
<context>
    <name>network</name>
    <message>
        <source>Network</source>
        <translation type="unfinished">Rrjet</translation>
    </message>
</context>
</TS>
